Examples
========

Parselmouth can be used in various contexts to combine Praat functionality with standard Python features or other Python libraries. The following examples give an idea of the range of possibilities:

.. toctree::
    :maxdepth: 2

    examples/plotting
    examples/batch_processing
    examples/pitch_manipulation
    examples/psychopy_experiments
    examples/web_service

.. only:: html

    .. note::

        An online, interactive version of these examples is available at Binder: |binder_badge_examples|


Projects using Parselmouth
--------------------------

The following projects provide larger, real-life examples and demonstrate the use of Parselmouth:

- The `my-voice-analysis <https://github.com/Shahabks/my-voice-analysis>`_ and `myprosody <https://github.com/Shahabks/myprosody>`_ projects by Shahab Sabahi (`@Shahabks <https://github.com/Shahabks>`_) provide Python libraries for voice analysis and acoustical statistics, interfacing Python to his previously developed Praat scripts.
- David R. Feinberg (`@drfeinberg <https://github.com/drfeinberg>`_) has written multiple Python scripts and programs with Parselmouth to analyse properties of speech recordings:

    - `Praat Scripts <https://osf.io/huz7d/>`_ is a collection of Praat scripts used in research, translated into Python.
    - `Voice Lab Software <https://osf.io/3wr6k/>`_ is a GUI application to measure and manipulate voices.

.. note::

    If you have a project using Parselmouth that could be useful for others, and want to add it to this list, do let us know on `Gitter <https://gitter.im/PraatParselmouth/Lobby>`_!
